:mod:`exspy.components`
-----------------------

.. currentmodule:: exspy.components

.. autosummary::

    DoublePowerLaw
    EELSArctan
    EELSCLEdge
    PESCoreLineShape
    PESVoigt
    SEE
    Vignetting
    VolumePlasmonDrude

.. automodule:: exspy.components
   :members:
